@@ -3,13 +3,13 @@
 (eval-when (load eval compile)
   (unless (member :GARNET lisp:*features*)
     (cerror "continue" "Garnet must be loaded before loading or compiling Multi-Garnet"))
-  (unless (or (equal "2.0" user::garnet-version-number)
-	      (equal "2.1" user::garnet-version-number))	      
+  (unless (or (equal "2.2" user::garnet-version-number)
+	      )
     (format t "~&Warning: Garnet version ~S is loaded~%" user::garnet-version-number)
-    (format t "~&    Multi-Garnet v2.1 has been tested in Garnet v2.0 and v2.1.~%")
+    (format t "~&    Multi-Garnet v2.2 has been tested in Garnet v2.2~%")
     (format t "~&    Multi-Garnet will probably not work with this version of Garnet.~%")
-    (cerror "compile Multi-Garnet v2.1"
-	    "Incompatible version of Garnet loaded: continue at your own risk")
+    (cerror "compile Multi-Garnet v2.2"
+            "Incompatible version of Garnet loaded: continue at your own risk")
     )
   )
 
@@ -27,8 +27,6 @@
     (disable-multi-garnet))
   )
 
-(compile-file "object-rep")
-(load "object-rep")
 (compile-file "sky-blue")
 (load "sky-blue")
 (compile-file "multi-garnet")
